# Using SedEdu

* This page will contain a walkthrough of the layout and functionality of SedEdu.
* It is intended for end-users and should be simple and tech-jargon free.


## Some ideas on ways to use it

* home-schooling
* on the board, used by instructor
* on class computers with an activity
* substitute teacher activity 
